@@ -13,7 +13,7 @@ package BSD::Resource;
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD $VERSION);
 
-$VERSION = '1.2906';
+$VERSION = '1.2908';
 
 use Carp;
 use AutoLoader;
@@ -38,12 +38,21 @@ require DynaLoader;
 	     RLIMIT_FSIZE
 	     RLIMIT_LOCKS
 	     RLIMIT_MEMLOCK
+	     RLIMIT_MSGQUEUE
+	     RLIMIT_NICE
 	     RLIMIT_NOFILE
 	     RLIMIT_NPROC
+	     RLIMIT_NPTS
 	     RLIMIT_OFILE
 	     RLIMIT_OPEN_MAX
+	     RLIMIT_PTHREAD
 	     RLIMIT_RSS
+	     RLIMIT_RTPRIO
+	     RLIMIT_RTTIME
+	     RLIMIT_SBSIZE
+	     RLIMIT_SIGPENDING
 	     RLIMIT_STACK
+	     RLIMIT_SWAP
 	     RLIMIT_TCACHE
 	     RLIMIT_VMEM
 	     RLIM_INFINITY
@@ -253,6 +262,7 @@ The $resource argument can be one of
         RLIMIT_AS               (virtual) address space bytes
         RLIMIT_VMEM             virtual memory (space)  bytes
 
+        RLIMIT_PTHREAD          number of pthreads      1
         RLIMIT_TCACHE           maximum number of       1
                                 cached threads
 
@@ -261,11 +271,24 @@ The $resource argument can be one of
         RLIMIT_AIO_OPS          maximum number          1
                                 for POSIX AIO ops
 
+        RLIMIT_SBSIZE           socket buffer size      bytes
+
+        RLIMIT_SWAP             maximum swap size       bytes
+
+        RLIMIT_MSGQUEUE         POSIX mq size           bytes
+
+        RLIMIT_RTPRIO           maximum RT priority     1
+        RLIMIT_RTTIME           maximum RT time         microseconds
+        RLIMIT_SIGPENDING       pending signals         1
+
 B<What limits are available depends on the operating system>.
+
 See below for C<get_rlimits()> on how to find out which limits are
 available, for the exact documentation consult the documentation of
-your operating system.  The two groups (C<NOFILE>, C<OFILE>,
-C<OPEN_MAX>) and (C<AS>, C<VMEM>) are aliases within themselves.
+your operating system (setrlimit documentation, usually).
+
+The two groups (C<NOFILE>, C<OFILE>, C<OPEN_MAX>) and (C<AS>, C<VMEM>)
+are aliases within themselves.
 
 Two meta-resource-symbols might exist
 
@@ -303,6 +326,9 @@ On failure it returns C<undef>.
 
 =head2 getpriority
 
+        # $pr_which can be PRIO_USER, PRIO_PROCESS, or PRIO_PGRP,
+        # and in some systems PRIO_THREAD
+
 	$nowpriority = getpriority($pr_which, $pr_who);
 
 	# the default $pr_who is 0 (the current $pr_which)
